@@ -126,7 +126,9 @@ namespace MagickCore
 #          pragma comment(lib, "CORE_DB_jpeg-turbo_.lib")
 #        endif
 #        if defined(MAGICKCORE_JXL_DELEGATE)
-#          pragma comment(lib, "CORE_DB_jxl_.lib")
+#          pragma comment(lib, "CORE_DB_highway_.lib")
+#          pragma comment(lib, "CORE_DB_brotli_.lib")
+#          pragma comment(lib, "CORE_DB_jpeg-xl_.lib")
 #        endif
 #        if defined(MAGICKCORE_LCMS_DELEGATE)
 #          pragma comment(lib, "CORE_DB_lcms_.lib")
@@ -162,6 +164,8 @@ namespace MagickCore
 #          pragma comment(lib, "CORE_DB_openjpeg_.lib")
 #        endif
 #        if defined(MAGICKCORE_PANGOCAIRO_DELEGATE)
+#          pragma comment(lib, "CORE_DB_fribidi_.lib")
+#          pragma comment(lib, "CORE_DB_harfbuzz_.lib")
 #          pragma comment(lib, "CORE_DB_pango_.lib")
 #          pragma comment(lib, "CORE_DB_pixman_.lib")
 #        endif
@@ -208,7 +212,9 @@ namespace MagickCore
 #          pragma comment(lib, "CORE_RL_jpeg-turbo_.lib")
 #        endif
 #        if defined(MAGICKCORE_JXL_DELEGATE)
-#          pragma comment(lib, "CORE_RL_jxl_.lib")
+#          pragma comment(lib, "CORE_RL_highway_.lib")
+#          pragma comment(lib, "CORE_RL_brotli_.lib")
+#          pragma comment(lib, "CORE_RL_jpeg-xl_.lib")
 #        endif
 #        if defined(MAGICKCORE_LCMS_DELEGATE)
 #          pragma comment(lib, "CORE_RL_lcms_.lib")
@@ -244,6 +250,8 @@ namespace MagickCore
 #          pragma comment(lib, "CORE_RL_openjpeg_.lib")
 #        endif
 #        if defined(MAGICKCORE_PANGOCAIRO_DELEGATE)
+#          pragma comment(lib, "CORE_RL_fribidi_.lib")
+#          pragma comment(lib, "CORE_RL_harfbuzz_.lib")
 #          pragma comment(lib, "CORE_RL_pango_.lib")
 #          pragma comment(lib, "CORE_RL_pixman_.lib")
 #        endif
